![](resources/skooting_in_progress_v2.png)

# SKOOTS

<img src="resources/overview.png" align="center" width="150px"/> 
SKeletOn ObjecT Segmentation - 2D/3D instance segmentation of arbitrary biomedical images.

## <img src="resources/installation.png" align="center" width="150px"/>

<!-- start installation -->
To install, make sure pyTorch 2.1 is installed with CUDA support.

```bash
pip install skoots
```

Documentation: skoots.readthedocs.io

BioRxiv: https://www.biorxiv.org/content/10.1101/2023.05.05.539611v1

